import * as i0 from '@angular/core';
import { Injectable, EventEmitter, Component, Input, Output, ViewChild, NgModule } from '@angular/core';
import * as i2 from '@ng-bootstrap/ng-bootstrap';
import { NgbDate, NgbDropdown, NgbModule, NgbDatepickerModule, NgbDropdownModule } from '@ng-bootstrap/ng-bootstrap';
import moment from 'moment-mini';
import * as i3 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import * as i4 from '@angular/common';
import { CommonModule } from '@angular/common';

/* eslint-disable @typescript-eslint/naming-convention */
// Object mapping display labels to date range options (keys)
const DATE_RANGE_OPTIONS = {
    Today: 'Today',
    Yesterday: 'Yesterday',
    Last7Days: 'Last7Days',
    Last28Days: 'Last28Days',
    Last30Days: 'Last30Days',
    Last90Days: 'Last90Days',
    ThisMonth: 'ThisMonth',
    LastMonth: 'LastMonth',
    Last12Months: 'Last12Months',
    LastCalendarYear: 'LastCalendarYear',
    ThisYear: 'ThisYear',
    Custom: 'Custom'
};

/* eslint-disable @typescript-eslint/naming-convention */
// Enum representing the available date ranges
var DateRange;
(function (DateRange) {
    DateRange["Today"] = "Today";
    DateRange["Yesterday"] = "Yesterday";
    DateRange["Last7Days"] = "Last 7 Days";
    DateRange["Last28Days"] = "Last 28 Days";
    DateRange["Last30Days"] = "Last 30 Days";
    DateRange["Last90Days"] = "Last 90 Days";
    DateRange["ThisMonth"] = "This Month";
    DateRange["LastMonth"] = "Last Month";
    DateRange["Last12Months"] = "Last 12 Months";
    DateRange["LastCalendarYear"] = "Last Calendar Year";
    DateRange["ThisYear"] = "This Year (Jan - Today)";
    DateRange["Custom"] = "Custom";
})(DateRange || (DateRange = {}));

/**
 * A utility class for the date range picker component
 */
class DateRangePickerUtils {
    constructor() { }
    /**
     * Returns the start and end dates of a given date range key as moment objects.
     *
     * @param dateRangeKey The string value representing the selected date range key.
     *
     * @returns An array of two moment.Moment objects representing the start and end dates of the selected date range.
     */
    getDateRangeAsMoments(dateRangeKey) {
        const dateRanges = this.getDefaultDateRanges();
        const [startDate, endDate] = dateRanges[dateRangeKey];
        return [moment(startDate), moment(endDate)];
    }
    /**
     * Returns the corresponding DateRange enum value based on a given string key.
     *
     * @param rangeKey The string value representing the selected date range key.
     *
     * @returns The corresponding DateRange enum value if found, or DateRange.Last28Days as a default.
     */
    getDateRangeFromKey(rangeKey) {
        const range = DateRange[rangeKey];
        return range !== undefined ? range : DateRange.Last28Days;
    }
    /**
     * Returns a formatted label for the selected date range, based on the provided start and end moment objects.
     *
     * @param fromMoment The moment object representing the start date of the selected date range.
     * @param toMoment The moment object representing the end date of the selected date range.
     *
     * @returns A formatted string label for the selected date range.
     */
    getSelectedRangeDateLabel(fromMoment, toMoment) {
        const dateFormat = 'DD MMM';
        const dateFormatWithYear = `${dateFormat} YYYY`;
        if (fromMoment.year() === toMoment.year()) {
            return `${fromMoment.format(dateFormat)}-${toMoment.format(dateFormatWithYear)}`;
        }
        else {
            return `${fromMoment.format(dateFormatWithYear)}-${toMoment.format(dateFormatWithYear)}`;
        }
    }
    /**
     * Focuses on a specific date in a NgbDatepicker component.
     *
     * @param dateRangerPicker The NgbDatepicker component to focus on.
     * @param fromDate The NgbDate object representing the date to focus on.
     *
     * @returns None.
     */
    focusDateInPicker(dateRangerPicker, fromDate) {
        dateRangerPicker?.focusDate(fromDate);
    }
    /**
     * Converts a moment object to a NgbDate object.
     *
     * @param momentObj The moment object to convert.
     *
     * @returns The corresponding NgbDate object.
     */
    convertToNgbDate(momentObj) {
        return new NgbDate(momentObj.year(), momentObj.month() + 1, momentObj.date());
    }
    /**
     * Closes the NgbDropdown component if it is open.
     *
     * @param dropdown The NgbDropdown component to close.
     *
     * @returns None.
     */
    closeDropDown(dropdown) {
        dropdown?.close();
    }
    /**
     * Returns an object containing default date ranges for the date range picker.
     *
     * @returns An object containing default date ranges, with the keys being the DateRange enum values and the values being arrays of start and end dates as strings.
     */
    getDefaultDateRanges() {
        const now = moment();
        const getNowCloned = (m) => m.clone();
        const dateRanges = {};
        for (const rangeKey of Object.keys(DateRange)) {
            const range = DateRange[rangeKey];
            switch (range) {
                case DateRange.Today:
                    dateRanges[rangeKey] = [getNowCloned(now).startOf('day'), getNowCloned(now).endOf('day')];
                    break;
                case DateRange.Yesterday:
                    dateRanges[rangeKey] = [getNowCloned(now).subtract(1, 'day').startOf('day'), getNowCloned(now).subtract(1, 'day').endOf('day')];
                    break;
                case DateRange.Last7Days:
                    dateRanges[rangeKey] = [getNowCloned(now).subtract(6, 'day').startOf('day'), getNowCloned(now)];
                    break;
                case DateRange.Last28Days:
                    dateRanges[rangeKey] = [getNowCloned(now).subtract(27, 'day').startOf('day'), getNowCloned(now)];
                    break;
                case DateRange.Last30Days:
                    dateRanges[rangeKey] = [getNowCloned(now).subtract(29, 'day').startOf('day'), getNowCloned(now)];
                    break;
                case DateRange.Last90Days:
                    dateRanges[rangeKey] = [getNowCloned(now).subtract(89, 'day').startOf('day'), getNowCloned(now)];
                    break;
                case DateRange.ThisMonth:
                    dateRanges[rangeKey] = [getNowCloned(now).startOf('month'), getNowCloned(now).endOf('month')];
                    break;
                case DateRange.LastMonth:
                    dateRanges[rangeKey] = [
                        getNowCloned(now).subtract(1, 'month').startOf('month'),
                        getNowCloned(now).subtract(1, 'month').endOf('month')
                    ];
                    break;
                case DateRange.Last12Months:
                    dateRanges[rangeKey] = [getNowCloned(now).subtract(11, 'month').startOf('month'), getNowCloned(now)];
                    break;
                case DateRange.LastCalendarYear:
                    dateRanges[rangeKey] = [
                        getNowCloned(now).subtract(1, 'year').startOf('year'),
                        getNowCloned(now).subtract(1, 'year').endOf('year')
                    ];
                    break;
                case DateRange.ThisYear:
                    dateRanges[rangeKey] = [getNowCloned(now).startOf('year'), getNowCloned(now)];
                    break;
                case DateRange.Custom:
                    dateRanges[rangeKey] = [getNowCloned(now), getNowCloned(now)];
                    break;
            }
        }
        return dateRanges;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.5", ngImport: i0, type: DateRangePickerUtils, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.5", ngImport: i0, type: DateRangePickerUtils }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.5", ngImport: i0, type: DateRangePickerUtils, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return []; } });

class DateRangePickerComponent {
    constructor(dateRangePickerUtils, calendar, formatter) {
        this.dateRangePickerUtils = dateRangePickerUtils;
        this.calendar = calendar;
        this.formatter = formatter;
        /**
         * The default date range option to show.
         * @default DATE_RANGE_OPTIONS.Last28Days
         */
        this.dateRangeKey = DATE_RANGE_OPTIONS.Last28Days;
        /**
         * The CSS class to apply to the "Apply" button.
         * @default 'btn-primary'
         */
        this.btnApplyClass = 'btn-primary';
        /**
         * The CSS class to apply to the date range picker.
         * @default ''
         */
        this.pickerCustomClass = '';
        /**
         * Emitted when the date range selection is changed.
         */
        this.rangeChanged = new EventEmitter();
        this.selectedDateRange = this.dateRangeKey; // Currently selected date range
        this.hoveredDate = null; // Currently hovered date for the custom date range
        this.dateRangeOptions = [];
    }
    ngOnInit() {
        this.dateRangeOptions = Object.entries(DateRange).map(([key, value]) => ({ key, value }));
        // Set the default date range option
        const [startDate, endDate] = this.dateRangePickerUtils.getDateRangeAsMoments(this.dateRangeKey);
        this.startNgbDate = this.dateRangePickerUtils.convertToNgbDate(startDate);
        this.endNgbDate = this.dateRangePickerUtils.convertToNgbDate(endDate);
        this.startDate = startDate;
        this.endDate = endDate;
        this.selectedRangeLabel = this.selectedRangeTempLabel = this.dateRangePickerUtils.getDateRangeFromKey(this.dateRangeKey);
        this.selectedRangeDateLabel = this.dateRangePickerUtils.getSelectedRangeDateLabel(startDate, endDate);
    }
    // onDateSelection(date: NgbDate) {
    //   if (!this.startNgbDate && !this.endNgbDate) {
    //     this.startNgbDate = date;
    //   } else if (this.startNgbDate && !this.endNgbDate && date && date.after(this.startNgbDate)) {
    //     this.endNgbDate = date;
    //   } else {
    //     this.endNgbDate = null;
    //     this.startNgbDate = date;
    //   }
    //   this.setRange(DATE_RANGE_OPTIONS.Custom);
    // }
    isHovered(date) {
        // Returns true if the start date, hovered date, and selected date satisfy the conditions for a range.
        return this.startNgbDate && !this.endNgbDate && this.hoveredDate && date.after(this.startNgbDate) && date.before(this.hoveredDate);
    }
    onDateSelection(date) {
        // If both the start and end dates are not set, set the start date to the selected date
        if (!this.startNgbDate && !this.endNgbDate) {
            this.startNgbDate = date;
        }
        // If the start date is set, but not the end date, and the selected date is after the start date, set the end date to the selected date
        else if (this.startNgbDate && !this.endNgbDate && date && date.after(this.startNgbDate)) {
            this.endNgbDate = date;
        }
        // Reset the selected dates if both the start and end dates are set, or if the selected date is before the start date.
        else {
            this.endNgbDate = null;
            this.startNgbDate = date;
        }
        // Update the date range to "Custom" and emit the rangeChanged event
        this.setRange(DATE_RANGE_OPTIONS.Custom);
    }
    isInside(date) {
        // Returns true if the end date is set, and the selected date is after the start date and before the end date
        return this.endNgbDate && date.after(this.startNgbDate) && date.before(this.endNgbDate);
    }
    isRange(date) {
        // Returns true if the selected date is the start date, the end date, inside the range, or hovered over
        return (date.equals(this.startNgbDate) || (this.endNgbDate && date.equals(this.endNgbDate)) || this.isInside(date) || this.isHovered(date));
    }
    validateInput(currentValue, input) {
        // Parses the input string and returns a NgbDate object if the input is valid and within the calendar range
        const parsed = this.formatter.parse(input);
        return parsed && this.calendar.isValid(NgbDate.from(parsed)) ? NgbDate.from(parsed) : currentValue;
    }
    changeDateRange(rangeKey, event) {
        // Stops the event from propagating and updates the date range
        event.stopPropagation();
        this.setRange(rangeKey);
    }
    cancel() {
        // Closes the dropdown menu
        this.dateRangePickerUtils.closeDropDown(this.dropdown);
    }
    isActiveRange(range) {
        return this.selectedRangeTempLabel === range;
    }
    apply() {
        this.selectedDateRangeKey = this.selectedDateRangeTempKey;
        // Update the selected range label
        this.selectedRangeLabel = this.selectedRangeTempLabel;
        // Calculate the selected range date label based on the selected date range
        this.selectedRangeDateLabel = this.dateRangePickerUtils.getSelectedRangeDateLabel(this.startDate, this.endDate);
        // Emit the range changed event with the selected range date range
        this.emitRangeChanged();
        // Close the date range picker dropdown
        this.dateRangePickerUtils.closeDropDown(this.dropdown);
    }
    setRange(dateRangeKey) {
        const dateRange = this.dateRangePickerUtils.getDateRangeFromKey(dateRangeKey);
        this.selectedDateRangeTempKey = dateRangeKey;
        // Check if the selected range is 'Custom'
        if (dateRangeKey === DATE_RANGE_OPTIONS.Custom) {
            // If the user has selected both the start and end date
            if (this.startNgbDate && this.endNgbDate) {
                // Set the selected range label to 'Custom'
                this.selectedRangeTempLabel = dateRange;
            }
        }
        else {
            // Get the start and end moments of the selected range
            const [startDate, endDate] = this.dateRangePickerUtils.getDateRangeAsMoments(dateRangeKey);
            // Convert start and end moments to NgbDate
            this.startNgbDate = this.dateRangePickerUtils.convertToNgbDate(startDate);
            this.endNgbDate = this.dateRangePickerUtils.convertToNgbDate(endDate);
            // Set the start and end dates
            this.startDate = startDate;
            this.endDate = endDate;
            // Set the selected range label
            this.selectedRangeTempLabel = dateRange;
            // Focus on the start date in the date picker
            this.dateRangePickerUtils.focusDateInPicker(this.dateRangerPicker, this.startNgbDate);
        }
    }
    emitRangeChanged() {
        // Emit event with selected date range and dates
        const dateRangeChange = {
            dateRange: this.selectedDateRangeKey,
            startDate: this.startDate,
            endDate: this.endDate
        };
        this.rangeChanged.emit(dateRangeChange);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.5", ngImport: i0, type: DateRangePickerComponent, deps: [{ token: DateRangePickerUtils }, { token: i2.NgbCalendar }, { token: i2.NgbDateParserFormatter }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.5", type: DateRangePickerComponent, selector: "app-date-range-picker", inputs: { dateRangeKey: "dateRangeKey", btnApplyClass: "btnApplyClass", pickerCustomClass: "pickerCustomClass" }, outputs: { rangeChanged: "rangeChanged" }, viewQueries: [{ propertyName: "dateRangerPicker", first: true, predicate: ["dp"], descendants: true }, { propertyName: "dropdown", first: true, predicate: NgbDropdown, descendants: true }], ngImport: i0, template: "<form>\n  <!-- <div class=\"mb-3\"> -->\n  <div class=\"d-flex flex-row {{ pickerCustomClass }}\">\n    <div class=\"p-2\">\n      <div class=\"d-inline-block\" #dropdown=\"ngbDropdown\" [autoClose]=\"'outside'\" ngbDropdown display=\"dynamic\">\n        <div class=\"d-flex align-items-center\" ngbDropdownToggle>\n          <div class=\"date-range-label me-2 p-1\">\n            {{ selectedRangeLabel }}\n          </div>\n          <div class=\"ms-auto d-flex align-items-center\">\n            <div class=\"me-2\">{{ selectedRangeDateLabel }}</div>\n          </div>\n        </div>\n        <div class=\"dropdown-menu date-range-dropdown\" ngbDropdownMenu aria-labelledby=\"dropdownRange\">\n          <div class=\"d-flex flex-row align-items-stretch\">\n            <div class=\"p-2 border-right dropdown-menu-options\">\n              <button\n                class=\"dropdown-item d-flex align-items-center justify-content-between\"\n                *ngFor=\"let range of dateRangeOptions\"\n                [ngClass]=\"{ active: isActiveRange(range.value) }\"\n                (click)=\"changeDateRange(range.key, $event)\"\n                ngbDropdownItem>\n                {{ range.value }}\n                <span class=\"ms-auto\" *ngIf=\"isActiveRange(range.value)\">&#x2713;</span>\n              </button>\n            </div>\n\n            <div class=\"p-2\">\n              <ngb-datepicker\n                #dp\n                [displayMonths]=\"2\"\n                [dayTemplate]=\"t\"\n                (dateSelect)=\"onDateSelection($event)\"\n                outsideDays=\"hidden\"></ngb-datepicker>\n\n              <ng-template #t let-date let-focused=\"focused\">\n                <span\n                  class=\"custom-day\"\n                  [class.focused]=\"focused\"\n                  [class.range]=\"isRange(date)\"\n                  [class.faded]=\"isHovered(date) || isInside(date)\"\n                  (mouseenter)=\"hoveredDate = date\"\n                  (mouseleave)=\"hoveredDate = null\">\n                  {{ date.day }}\n                </span>\n              </ng-template>\n            </div>\n          </div>\n          <div class=\"dropdown-divider\"></div>\n          <div class=\"d-flex flex-row justify-content-end align-items-center px-3 py-2\">\n            <button class=\"btn btn-sm btn-secondary me-2\" (click)=\"cancel()\" type=\"button\">Cancel</button>\n            <button class=\"btn btn-sm {{ btnApplyClass }}\" (click)=\"apply()\" type=\"button\">Apply</button>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n  <!-- </div> -->\n</form>\n", styles: [".custom-day{text-align:center;padding:.185rem .25rem;display:inline-block;height:2rem;width:2rem}.custom-day.focused,.custom-day.range,.custom-day:hover{color:var(--bs-dropdown-link-hover-color);background-color:#dddfe2}.custom-day.faded{background-color:var(--bs-dropdown-link-hover-bg)}.dropdown-menu .btn{padding:.25rem 1rem}.dropdown-menu-options{min-width:280px}ngb-datepicker{border:none}.border-right{border-right:1px solid #ccc;height:100%;margin-left:10px;margin-right:10px}.dropdown-toggle:hover{cursor:pointer}.date-range-label{background-color:#eaeaea;font-size:.8em}\n"], dependencies: [{ kind: "directive", type: i3.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i3.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i3.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i4.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i2.NgbDatepicker, selector: "ngb-datepicker", inputs: ["contentTemplate", "dayTemplate", "dayTemplateData", "displayMonths", "firstDayOfWeek", "footerTemplate", "markDisabled", "maxDate", "minDate", "navigation", "outsideDays", "showWeekNumbers", "startDate", "weekdays"], outputs: ["navigate", "dateSelect"], exportAs: ["ngbDatepicker"] }, { kind: "directive", type: i2.NgbDropdown, selector: "[ngbDropdown]", inputs: ["autoClose", "dropdownClass", "open", "placement", "popperOptions", "container", "display"], outputs: ["openChange"], exportAs: ["ngbDropdown"] }, { kind: "directive", type: i2.NgbDropdownToggle, selector: "[ngbDropdownToggle]" }, { kind: "directive", type: i2.NgbDropdownMenu, selector: "[ngbDropdownMenu]" }, { kind: "directive", type: i2.NgbDropdownItem, selector: "[ngbDropdownItem]", inputs: ["disabled"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.5", ngImport: i0, type: DateRangePickerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'app-date-range-picker', template: "<form>\n  <!-- <div class=\"mb-3\"> -->\n  <div class=\"d-flex flex-row {{ pickerCustomClass }}\">\n    <div class=\"p-2\">\n      <div class=\"d-inline-block\" #dropdown=\"ngbDropdown\" [autoClose]=\"'outside'\" ngbDropdown display=\"dynamic\">\n        <div class=\"d-flex align-items-center\" ngbDropdownToggle>\n          <div class=\"date-range-label me-2 p-1\">\n            {{ selectedRangeLabel }}\n          </div>\n          <div class=\"ms-auto d-flex align-items-center\">\n            <div class=\"me-2\">{{ selectedRangeDateLabel }}</div>\n          </div>\n        </div>\n        <div class=\"dropdown-menu date-range-dropdown\" ngbDropdownMenu aria-labelledby=\"dropdownRange\">\n          <div class=\"d-flex flex-row align-items-stretch\">\n            <div class=\"p-2 border-right dropdown-menu-options\">\n              <button\n                class=\"dropdown-item d-flex align-items-center justify-content-between\"\n                *ngFor=\"let range of dateRangeOptions\"\n                [ngClass]=\"{ active: isActiveRange(range.value) }\"\n                (click)=\"changeDateRange(range.key, $event)\"\n                ngbDropdownItem>\n                {{ range.value }}\n                <span class=\"ms-auto\" *ngIf=\"isActiveRange(range.value)\">&#x2713;</span>\n              </button>\n            </div>\n\n            <div class=\"p-2\">\n              <ngb-datepicker\n                #dp\n                [displayMonths]=\"2\"\n                [dayTemplate]=\"t\"\n                (dateSelect)=\"onDateSelection($event)\"\n                outsideDays=\"hidden\"></ngb-datepicker>\n\n              <ng-template #t let-date let-focused=\"focused\">\n                <span\n                  class=\"custom-day\"\n                  [class.focused]=\"focused\"\n                  [class.range]=\"isRange(date)\"\n                  [class.faded]=\"isHovered(date) || isInside(date)\"\n                  (mouseenter)=\"hoveredDate = date\"\n                  (mouseleave)=\"hoveredDate = null\">\n                  {{ date.day }}\n                </span>\n              </ng-template>\n            </div>\n          </div>\n          <div class=\"dropdown-divider\"></div>\n          <div class=\"d-flex flex-row justify-content-end align-items-center px-3 py-2\">\n            <button class=\"btn btn-sm btn-secondary me-2\" (click)=\"cancel()\" type=\"button\">Cancel</button>\n            <button class=\"btn btn-sm {{ btnApplyClass }}\" (click)=\"apply()\" type=\"button\">Apply</button>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n  <!-- </div> -->\n</form>\n", styles: [".custom-day{text-align:center;padding:.185rem .25rem;display:inline-block;height:2rem;width:2rem}.custom-day.focused,.custom-day.range,.custom-day:hover{color:var(--bs-dropdown-link-hover-color);background-color:#dddfe2}.custom-day.faded{background-color:var(--bs-dropdown-link-hover-bg)}.dropdown-menu .btn{padding:.25rem 1rem}.dropdown-menu-options{min-width:280px}ngb-datepicker{border:none}.border-right{border-right:1px solid #ccc;height:100%;margin-left:10px;margin-right:10px}.dropdown-toggle:hover{cursor:pointer}.date-range-label{background-color:#eaeaea;font-size:.8em}\n"] }]
        }], ctorParameters: function () { return [{ type: DateRangePickerUtils }, { type: i2.NgbCalendar }, { type: i2.NgbDateParserFormatter }]; }, propDecorators: { dateRangeKey: [{
                type: Input
            }], btnApplyClass: [{
                type: Input
            }], pickerCustomClass: [{
                type: Input
            }], rangeChanged: [{
                type: Output
            }], dateRangerPicker: [{
                type: ViewChild,
                args: ['dp']
            }], dropdown: [{
                type: ViewChild,
                args: [NgbDropdown]
            }] } });

class DateRangePickerModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.5", ngImport: i0, type: DateRangePickerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.5", ngImport: i0, type: DateRangePickerModule, declarations: [DateRangePickerComponent], imports: [FormsModule, CommonModule, NgbModule, NgbDatepickerModule, NgbDropdownModule], exports: [DateRangePickerComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.5", ngImport: i0, type: DateRangePickerModule, providers: [DateRangePickerUtils] // Services provided by this module
        , imports: [FormsModule, CommonModule, NgbModule, NgbDatepickerModule, NgbDropdownModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.5", ngImport: i0, type: DateRangePickerModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [DateRangePickerComponent],
                    imports: [FormsModule, CommonModule, NgbModule, NgbDatepickerModule, NgbDropdownModule],
                    exports: [DateRangePickerComponent],
                    providers: [DateRangePickerUtils] // Services provided by this module
                }]
        }] });

/* eslint-disable @typescript-eslint/naming-convention */
// Enum representing the available date ranges
var DateRangeOptionEnum;
(function (DateRangeOptionEnum) {
    DateRangeOptionEnum[DateRangeOptionEnum["Today"] = 0] = "Today";
    DateRangeOptionEnum[DateRangeOptionEnum["Yesterday"] = 1] = "Yesterday";
    DateRangeOptionEnum[DateRangeOptionEnum["Last7Days"] = 2] = "Last7Days";
    DateRangeOptionEnum[DateRangeOptionEnum["Last28Days"] = 3] = "Last28Days";
    DateRangeOptionEnum[DateRangeOptionEnum["Last30Days"] = 4] = "Last30Days";
    DateRangeOptionEnum[DateRangeOptionEnum["Last90Days"] = 5] = "Last90Days";
    DateRangeOptionEnum[DateRangeOptionEnum["ThisMonth"] = 6] = "ThisMonth";
    DateRangeOptionEnum[DateRangeOptionEnum["LastMonth"] = 7] = "LastMonth";
    DateRangeOptionEnum[DateRangeOptionEnum["Last12Months"] = 8] = "Last12Months";
    DateRangeOptionEnum[DateRangeOptionEnum["LastCalendarYear"] = 9] = "LastCalendarYear";
    DateRangeOptionEnum[DateRangeOptionEnum["ThisYear"] = 10] = "ThisYear";
    DateRangeOptionEnum[DateRangeOptionEnum["Custom"] = 11] = "Custom";
})(DateRangeOptionEnum || (DateRangeOptionEnum = {}));

/*
 * Public API Surface of ng-bootstrap-date-range-picker
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DATE_RANGE_OPTIONS, DateRangeOptionEnum, DateRangePickerComponent, DateRangePickerModule, DateRangePickerUtils };
//# sourceMappingURL=kokotree-inc-ng-bootstrap-date-range-picker.mjs.map
